@@ -1,6 +1,7 @@
 import asyncio
 import datetime
 import logging
+import pprint
 import re
 from textwrap import shorten
 from urllib.parse import urljoin
@@ -35,7 +36,7 @@ class QCticAPI:
 
     DEFAULT_HOST = "http://localhost"
 
-    def __init__(self, host=DEFAULT_HOST):
+    def __init__(self, host=DEFAULT_HOST, request_timeout=300):
         """Constructor.
 
         Args:
@@ -49,7 +50,11 @@ class QCticAPI:
 
             host = "{}://{}".format(_SCHEME_DEFAULT, host)
 
-        self._req_defaults = {"headers": {"Content-Type": "application/json"}}
+        self._req_defaults = {
+            "headers": {"Content-Type": "application/json"},
+            "request_timeout": float(request_timeout)
+        }
+
         self._client = None
         self._host = host
         self._loop = None
@@ -156,14 +161,24 @@ class QCticAPI:
         request_params.update(kwargs)
         return HTTPRequest(**request_params)
 
+    def _raise_qctic_api_error(self, fetch_ex):
+        try:
+            body = json_decode(fetch_ex.response.body)
+            _logger.warning("API error response:\n%s", pprint.pformat(body))
+            body_name = body.get("name", "Undefined error name")
+            body_desc = body.get("description", "Undefined error description")
+            msg_err = "[{}] {}".format(body_name, body_desc)
+        except:
+            msg_err = "{}".format(repr(fetch_ex))
+
+        raise QCticAPIError(msg_err)
+
     async def _fetch(self, *args, **kwargs):
         try:
             return await self.client.fetch(*args, **kwargs)
         except HTTPError as ex:
-            err = json_decode(ex.response.body)
-            _logger.warning("Error on API request: %s", err)
-            err_msg = "[{}] {}".format(err.get("name"), err.get("description"))
-            raise QCticAPIError(err_msg)
+            _logger.warning("Error on HTTP fetch", exc_info=True)
+            self._raise_qctic_api_error(fetch_ex=ex)
 
     async def get_job(self, job_id, lean=False):
         """Retrieves a single Job from the API.
