@@ -17,9 +17,10 @@ def fake_circuit():
     return circuit
 
 
-def fake_qobj():
+def fake_qobj(circuit=None):
     backend = Aer.get_backend("qasm_simulator")
-    return assemble(fake_circuit(), backend)
+    circuit = circuit or fake_circuit()
+    return assemble(circuit, backend)
 
 
 def fake_job_dict():
